import { MathStyle, RenderMode, RadicalDegreeAlgorithm } from "./enums";
import type { FontData } from "@math-blocks/opentype";
export declare type Context = {
    readonly fontData: FontData;
    readonly baseFontSize: number;
    readonly mathStyle: MathStyle;
    readonly cramped: boolean;
    readonly operator?: boolean;
    readonly renderMode: RenderMode;
    readonly radicalDegreeAlgorithm?: RadicalDegreeAlgorithm;
};
export declare type Dist = number;
export declare type Dim = Readonly<{
    readonly width: Dist;
    readonly depth: Dist;
    readonly height: Dist;
}>;
declare type Style = {
    readonly color?: string;
    readonly cancel?: number;
};
declare type Common = {
    readonly id?: number;
    readonly style: Style;
};
export declare type Content = {
    readonly type: "static";
    readonly nodes: readonly Node[];
} | {
    readonly type: "cursor";
    readonly left: readonly Node[];
    readonly right: readonly Node[];
} | {
    readonly type: "selection";
    readonly left: readonly Node[];
    readonly selection: readonly Node[];
    readonly right: readonly Node[];
};
export declare type HBox = {
    readonly type: "HBox";
    readonly shift: Dist;
    readonly content: Content;
    readonly fontSize: number;
} & Common & Dim;
export declare type VBox = {
    readonly type: "VBox";
    readonly shift: Dist;
    readonly content: readonly Node[];
    readonly fontSize: number;
} & Common & Dim;
export declare type Glyph = {
    readonly type: "Glyph";
    readonly char?: string;
    readonly glyphID: number;
    readonly size: number;
    readonly fontData: FontData;
    readonly pending?: boolean;
} & Common;
export declare type Kern = {
    readonly type: "Kern";
    readonly size: Dist;
    readonly flag?: "start" | "end";
} & Common;
export declare type HRule = {
    readonly type: "HRule";
    readonly thickness: number;
    readonly width: number;
} & Common;
export declare type Node = HBox | VBox | Glyph | Kern | HRule;
export {};
